@@ -28,6 +28,7 @@ class MathTermClass(MathSegmentClass):
     @classmethod
     def CreateTermFromText(cls, text) -> 'MathTermClass':
         index = 0
+        is_num = False
         start_with_sign = False
         if text[index] == '-' or text[index] == '+':
             start_with_sign = True
@@ -36,9 +37,11 @@ class MathTermClass(MathSegmentClass):
         while index < len(text) and (text[index].isdigit() or (not period_used and text[index] == '.')):
             if text[index] == '.' and not period_used:
                 period_used = True
+            else:
+                is_num = True
             index += 1
 
-        if index == 0 or (start_with_sign and index == 1):
+        if not is_num:
             return cls(0, None)
             # raise Exception("could not find number in text '{}'".format(text))
 
